Index: webrtc/p2p/client/basicportallocator_unittest.cc |
diff --git a/webrtc/p2p/client/basicportallocator_unittest.cc b/webrtc/p2p/client/basicportallocator_unittest.cc |
index 4ace7c8a3c20496f7038b7300888bca6db7d6c38..8ca370c49a1f92e86dc39034f312c906411df106 100644 |
--- a/webrtc/p2p/client/basicportallocator_unittest.cc |
+++ b/webrtc/p2p/client/basicportallocator_unittest.cc |
@@ -83,11 +83,11 @@ static const int kDefaultAllocationTimeout = 3000; |
static const char kTurnUsername[] = "test"; |
static const char kTurnPassword[] = "test"; |
// STUN timeout (with all retries) is 9500ms. |
// Add some margin of error for slow bots. |
// TODO(deadbeef): Use simulated clock instead of just increasing timeouts to |
// fix flaky tests. |
-static const int kStunTimeoutMs = 15000; |
+static const int kStunTimeoutMs = cricket::STUN_TOTAL_TIMEOUT + 5000; |
namespace cricket { |
@@ -83,11 +83,11 @@ static const int kDefaultAllocationTimeout = 3000; |
static const char kTurnUsername[] = "test"; |
static const char kTurnPassword[] = "test"; |
-// STUN timeout (with all retries) is 9500ms. |
+// STUN timeout (with all retries) is cricket::STUN_TOTAL_TIMEOUT. |
// Add some margin of error for slow bots. |
// TODO(deadbeef): Use simulated clock instead of just increasing timeouts to |